@@ -1,4 +1,4 @@
-/* $Id: glibmm.h,v 1.2 2004/03/02 23:29:56 murrayc Exp $ */
+/* $Id: glibmm.h,v 1.4 2004/10/10 21:03:41 murrayc Exp $ */
 
 /* glibmm - a C++ wrapper for the GLib toolkit
  *
@@ -37,6 +37,7 @@
 #include <glibmm/helperlist.h>
 #include <glibmm/interface.h>
 #include <glibmm/iochannel.h>
+#include <glibmm/init.h>
 #include <glibmm/streamiochannel.h>
 #include <glibmm/listhandle.h>
 #include <glibmm/main.h>
@@ -45,6 +46,7 @@
 #include <glibmm/module.h>
 #include <glibmm/objectbase.h>
 #include <glibmm/object.h>
+#include <glibmm/optioncontext.h>
 #include <glibmm/pattern.h>
 #include <glibmm/property.h>
 #include <glibmm/propertyproxy_base.h>
